@@ -1,7 +1,6 @@
-grfx <- function(n, G, incidence = NULL, saveIncidence = FALSE, output = "matrix", warn = TRUE){
-
-  d <- dim(G)[1]
-  if(all(G == G[1,1]) & d > 1) warning("variance-covariance matrix 'G' may have caused 'chol.default(G)' error.  If so, consider subtracting 0.0001 from the covariances to make correlations < 1 or >-1")
+grfx <- function(n, G, incidence = NULL, saveIncidence = FALSE, output = "matrix", stdnorms = NULL, warn = TRUE){
+  d <- nrow(G)
+  if(d > 1 && all(G == G[1,1])) warning("variance-covariance matrix 'G' may have caused 'chol.default(G)' error.  If so, consider subtracting 0.0001 from the covariances to make correlations < 1 or >-1")
   Mg <- as(chol(G), "dtCMatrix")
   if(is.null(incidence)){
      if(any(ls(envir = globalenv() ) == "nadiv_prev_Mincidence")){
@@ -12,7 +11,7 @@ grfx <- function(n, G, incidence = NULL, saveIncidence = FALSE, output = "matrix
              } else{
                   nadiv_prev_Mincidence <- Diagonal(n, 1)
                }
-          warning("Incidence matrix used = Identity matrix")
+          if(warn) warning("Incidence matrix used = Identity matrix")
        }
   } else{
        if(saveIncidence){
@@ -23,7 +22,12 @@ grfx <- function(n, G, incidence = NULL, saveIncidence = FALSE, output = "matrix
     }
 
   M <- suppressMessages(kronecker(nadiv_prev_Mincidence, Mg))
-  Z <- Matrix(rnorm(n*d), nrow = 1)
+  if(is.null(stdnorms)){
+     Z <- Matrix(rnorm(n*d), nrow = 1)
+  } else{
+       if(length(stdnorms) != n*d) stop("length(stdnorms) must be equal to 'n' times the order of 'G'")
+       Z <- Matrix(stdnorms, nrow = 1)
+    }
   X <- Matrix((Z %*% M)@x, ncol = d, byrow = TRUE)
 
  return(as(X, output))
